@@ -1,6 +1,5 @@
 """Language for describing events that in terminal"""
 import sys
-import threading
 
 PY3 = sys.version_info[0] >= 3
 
@@ -32,23 +31,36 @@ class SigIntEvent(Event):
     def name(self):
         return repr(self)
 
-def get_key(chars, use_curses_name=True):
+def get_key(chars, keynames='curses'):
     if not ((chars and chars[0] != '\x1b') or
             (len(chars) == 2 and chars[1] not in ['[', 'O', '\x1b']) or
             (len(chars) == 4 and chars[1] == '\x1b' and chars[2] == '[') or
             (len(chars) > 2 and chars[1] in ['[', 'O'] and chars[-1] not in tuple('1234567890;'))):
         return None
-    try:
-        if PY3:
+    if PY3:
+        try:
             u = ''.join(chars)
-        else:
-            u = ''.join(chars).decode('utf8')
-    except UnicodeDecodeError:
-        return None
-    return curses_name(u)
+        except UnicodeDecodeError:
+            return None
+    else:
+        chars = ''.join(chars)
+        if len(chars) == 1 and 0x80 <= ord(chars) <= 0xff:
+            return unicode(chars, 'latin') # option-key
+        try:
+            u = chars.decode('utf8')
+        except UnicodeDecodeError:
+            return None
+    if keynames == 'curses':
+        return curses_name(u)
+    elif keynames == 'fmtstr':
+        return fmtstr_name(u)
+    elif keynames is None or keynames == 'plain':
+        return u
+    else:
+        raise ValueError('keyname must but one of "fmtstr", "curses"')
 
 def pp_event(seq):
-    """Returns pretty version of an Event or keypress"""
+    """Returns pretty representation of an Event or keypress"""
 
     if isinstance(seq, Event):
         return str(seq)
@@ -56,22 +68,36 @@ def pp_event(seq):
     if seq in REVERSE_CURSES:
         seq = REVERSE_CURSES[seq]
 
+    fsname = fmtstr_name(seq)
+    if fsname != seq:
+        return fsname
+    return repr(seq)[2:-1]
+
+def fmtstr_name(seq):
+    if isinstance(seq, Event):
+        return seq
+
     if seq in SEQUENCE_NAMES:
         return SEQUENCE_NAMES[seq]
     if len(seq) == 1 and '\x00' < seq < '\x1a':
         return '<Ctrl-%s>' % chr(ord(seq) + 0x60)
+    if len(seq) == 1 and 0x80 <= ord(seq) <= 0xff:
+        c = chr(ord(seq) - 0x80)
+        if '\x00' < c < '\x1a':
+            return '<Ctrl-Option-%s>' % chr(ord(c) + 0x60)
+        return '<Option-%s>' % repr(c)[1:-1]
+        #TODO decide between Option-\\ vs Option-\
+        # (currently Option-\\, caused by repl calr)
     if len(seq) == 2 and seq[0] == '\x1b':
         if '\x00' < seq[1] < '\x1a':
             return '<Ctrl-Meta-%s>' % chr(ord(seq[1]) + 0x60)
         return '<Meta-%s>' % seq[1]
-    if seq[0] == '':
-        pass
-    return repr(seq)[2:-1]
+    return seq
 
 def curses_name(seq):
     return CURSES_TABLE.get(seq, seq)
 
-# the first one is the canonical name, the rest are used for equivalence
+# the first one is the canonical name, the second is the pretty str
 SEQUENCE_NAMES = dict([
   (' ',        '<SPACE>'),
   ('\x1b ',    '<Meta-SPACE>'),
@@ -105,6 +131,11 @@ SEQUENCE_NAMES = dict([
   ('\x1f', '<Ctrl-/>'),
   ('\x7f', '<DELETE>'),
   ('\x1b\x7f', '<Meta-DELETE>'),
+  ('\xff', '<Option-DELETE>'),
+  ('\x1b\x1b[A',   '<Option-UP>'),
+  ('\x1b\x1b[B',   '<Option-DOWN>'),
+  ('\x1b\x1b[C',   '<Option-RIGHT>'),
+  ('\x1b\x1b[D',   '<Option-LEFT>'),
   ])
 
 CURSES_TABLE = {}
@@ -124,6 +155,7 @@ CURSES_TABLE['\x08'] = 'KEY_BACKSPACE'
 CURSES_TABLE['\x1b[3~'] = 'KEY_DC'
 CURSES_TABLE['\x1b[5~'] = 'KEY_PPAGE'
 CURSES_TABLE['\x1b[6~'] = 'KEY_NPAGE'
+CURSES_TABLE['\x1b[Z'] = 'KEY_BTAB'
 #TODO add home and end? and everything else
 
 REVERSE_CURSES = dict((v, k) for k, v in CURSES_TABLE.items())
