@@ -7,7 +7,6 @@ inspired by
 https://github.com/gwk/gloss/blob/master/python/gloss/io/cs.py
 """
 
-import os
 import sys
 import tty
 import signal
@@ -84,7 +83,7 @@ class TerminalController(object):
         if self.orig_sigint_handler:
             signal.signal(signal.SIGINT, self.orig_sigint_handler)
         termios.tcsetattr(self.out_stream, termios.TCSANOW, self.original_stty)
-        #os.system('stty '+self.original_stty)
+        #import os; os.system('stty '+self.original_stty)
 
     up, down, forward, back = [produce_cursor_sequence(c) for c in 'ABCD']
     fwd = forward
@@ -99,13 +98,8 @@ class TerminalController(object):
     def stuff_a_refresh_request(self):
         self.queued_refresh_request = True
 
-    def get_event_curses(self):
-        """get event, with keypress events translated to their curses equivalent"""
-        e = self.get_event()
-        return e.curses()
-
-    def get_event(self, use_curses_aliases=True, fake_input=None):
-        """Blocks and returns the next event"""
+    def get_event(self, keynames='curses', fake_input=None):
+        """Blocks and returns the next event, using curses names by default"""
         #TODO make this cooler - generator? Trie?
         chars = []
         while True:
@@ -126,7 +120,7 @@ class TerminalController(object):
 
             logging.debug('getting key for %r', chars)
             logging.debug('self.in_buffer %r', self.in_buffer)
-            c = events.get_key(chars, use_curses_name=use_curses_aliases)
+            c = events.get_key(chars, keynames=keynames)
             if c:
                 return c
             if fake_input:
@@ -195,16 +189,18 @@ def test():
         tc.write(pos)
         tc.back(len(pos))
         tc.scroll_down()
-        tc.write('asdf')
-        tc.back(4)
+        tc.write('Control-D to exit')
+        tc.back(len('Control-D to exit'))
         tc.scroll_down()
-        tc.write('asdf')
+        tc.write('....')
         tc.back(4)
         while True:
-            e = tc.get_event()
-            if e != 's':
+            e = tc.get_event(keynames=None)
+            if e in events.CURSES_TABLE:
+                data = "%r : %s, but called %s for curses compatibility" % (e, events.pp_event(e), events.CURSES_TABLE[e])
+            else:
                 data = "%r : %s" % (e, events.pp_event(e))
-                tc.write(data)
+            tc.write(data)
             tc.scroll_down()
             tc.back(len(data))
             if e == '':
